#PBS -l nodes=16:ppn=4:opteron
#PBS -l walltime=50:0:0
#PBS -o stdout.log
#PBS -e stderr.log

import numpy as np
from ase.io import read
from gpaw.utilities import h2gpts
from gpaw import GPAW, Mixer, PoissonSolver, FermiDirac
from ase.optimize import QuasiNewton
import os

hostname = os.uname()[1]
if hostname.startswith('m'):
    raise SystemExit

system = read('geom.traj')

calc = GPAW(mode='lcao',
            nbands=900,
            basis={'Ti': 'dz', None: 'dzp'},
            gpts=h2gpts(0.2, system.get_cell(), idiv=8),
            xc='RPBE',
            occupations=FermiDirac(0.1, maxiter=3000),
            kpts=(2, 4, 1),
            txt='gpaw.txt',
            maxiter=240,
            parallel=dict(sl_default=(4, 2, 2)),
            poissonsolver=PoissonSolver(relax='GS', eps=1e-9),
            mixer=Mixer(0.04, 7, 15.0))

opt = QuasiNewton(system, trajectory='opt.traj', logfile='opt.log')

system.set_calculator(calc)
opt.run(fmax=0.05)
