from ase.lattice.surface import fcc111
from ase.visualize import view
from ase.io import write
from ase.constraints import FixAtoms
import numpy as np
from ase.lattice.tetragonal import SimpleTetragonalFactory

class TiO2Factory(SimpleTetragonalFactory):
        u=0.305
        bravais_basis = [[0, 0, 0],[0.5, 0.5, 0.5],[u, u, 0],[1-u, 1-u, 0],[0.5\
+u,0.5-u, 0.5],[0.5-u, 0.5+u, 0.5]]
        element_basis = (0, 0, 1, 1, 1, 1)

TiO2 = TiO2Factory()

#TiO2110 surface                                                                
system = TiO2(directions= [[1,-1,0],[0,0,-1],[1, 1, 0]],
              size=(3,2,2), symbol=('Ti', 'O'), pbc=(1,1,0),
              latticeconstant={'a':4.6719, 'c':2.9711})
slab = system
pos = slab.get_positions()
# m is 1...N atoms                                                              
#n[0] is x, n[2] is z                                                           
for m,n in enumerate(pos):
    if n[2] < 0.1:
         pos[m,2]+= system.cell[2,2]

slab.set_positions(pos)


surface = fcc111('Pt', size=(2, 8, 3), orthogonal=True)

cell = surface.get_cell()
cell[1, 1] = system.cell[0, 0]
cell[0, 0] = system.cell[1, 1]
surface.set_cell(cell, scale_atoms=True)
surface.rotate([1.,0.,0.], [0.,-1.,0.])

system.center(vacuum=5.0, axis=2)

#system.positions[:, 2] = -1.0
#surface.set_cell(system.cell, scale_atoms=True)
maxz = system.positions[:, 2].max()
Ptcoord = maxz + 2.5
surface.positions[:, 2] += -surface.positions[:, 2].min() + Ptcoord
surface.positions[:, 1] *= -1.0



system += surface

system.center(vacuum=5.0, axis=2)

maxzO = system.positions[system.numbers == 8][:, 2].max()
print maxzO
mask = system.positions[:, 2] < maxzO

sys1 = system.copy()
del sys1[np.abs(sys1.positions[:, 2] - maxzO) < 1e-3]
#mask1 = sys1.positions[:, 2] < maxzO
sys1.set_constraint(FixAtoms(mask=sys1.numbers != 78))
write('adhesion.reduced.traj', sys1)


constraint = FixAtoms(mask=mask)

system.set_constraint(constraint)

write('adhesion.traj', system)
#view(system)
